import Adw from 'gi://Adw';
import Gio from 'gi://Gio';
import Gtk from 'gi://Gtk';
import { ExtensionPreferences, gettext as _, } from 'resource:///org/gnome/Shell/Extensions/js/extensions/prefs.js';
import { Keys } from './lib/keys.js';
export default class WindowDesaturationPreferences extends ExtensionPreferences {
    async fillPreferencesWindow(window) {
        window._settings = this.getSettings();
        Gio.Resource.load(`${this.path}/resources.gresource`)._register();
        const builder = Gtk.Builder.new_from_resource('/org/gnome/Shell/Extensions/window-desaturation/general.ui');
        window.add(builder.get_object('general'));
        window._settings.bind(Keys.desaturate_overview, builder.get_object('overview'), 'active', Gio.SettingsBindFlags.DEFAULT);
        // FIXME: bind_with_mapping fails for some reason
        window._settings.bind(Keys.background_factor, builder.get_object('backgroundFactor'), 'value', Gio.SettingsBindFlags.DEFAULT);
        window._settings.bind(Keys.desaturate_hover, builder.get_object('hover'), 'active', Gio.SettingsBindFlags.DEFAULT);
        window._settings.bind(Keys.desaturate_hover, builder.get_object('hoverRow'), 'sensitive', Gio.SettingsBindFlags.DEFAULT);
        // FIXME: bind_with_mapping fails for some reason
        window._settings.bind(Keys.hover_factor, builder.get_object('hoverFactor'), 'value', Gio.SettingsBindFlags.DEFAULT);
        function fillIgnoredApplications() {
            refresh_ignored_applications(builder.get_object('ignored-applications'), window._settings.get_strv(Keys.ignored_applications), (ignored) => window._settings.set_strv(Keys.ignored_applications, ignored));
        }
        fillIgnoredApplications();
        window._settings.connect(`changed::${Keys.ignored_applications}`, () => fillIgnoredApplications());
    }
}
function refresh_ignored_applications(box, ignored, callback) {
    box.remove_all();
    ignored.forEach((title, index) => {
        const row = new Adw.ActionRow({ title });
        const button = new Gtk.Button({
            icon_name: 'list-remove-symbolic',
            valign: Gtk.Align.CENTER,
            css_classes: ['circular', 'destructive-action'],
        });
        button.connect('clicked', () => {
            ignored.splice(index, 1);
            callback(ignored);
        });
        row.add_suffix(button);
        box.append(row);
    });
    const row = new Adw.EntryRow({
        title: _('Add application to ignore'),
        show_apply_button: true,
    });
    row.connect('apply', () => {
        ignored.push(row.text);
        row.delete_text(0, -1);
        callback(ignored);
    });
    box.append(row);
}
